@@ -47,7 +47,7 @@ def download_url(url, root, filename, md5=None, dry_run=False):
 
     try:
         urlretrieve = urllib.request.urlretrieve
-    else:
+    except ImportError:
         urlretrieve = urllib.urlretrieve
 
     root = os.path.expanduser(root)
